# -*- coding: utf-8 -*-
"""
Created on Thu Nov 12 16:37:59 2020

@author: pierr
"""
import os
def run():
    exec(open("backtest/webapp.py").read())
